<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Modo avión activado</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Modo avión desactivado</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Permitir</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo avión</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Ajustes de modo avión</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo avión</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Mis dispositivos</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ajustes de Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
        <translation>Desactive primero el modo avión si desea conectarse a un Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ajustes de Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectado</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Conectando...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Conectado %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>No conectado</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Brillo</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Ajustes de Pantalla</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Ajustes de Pantalla</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Brillo</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>dom.</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>lun.</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>mar.</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>miérc.</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>juev.</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>vier.</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>sáb.</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Añadir distribución de teclado</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Fecha y hora</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Formato de 12 horas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Formato de 24 horas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Ajustes de fecha y hora</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Abrir el calendario</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>domingo</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>lunes</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>martes</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>miércoles</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>jueves</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>viernes</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sábado</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>domingo</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Otros dispositivos</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Modo DND</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Ajustes de modo DND</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Modo DND activado</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Modo DND desactivado</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Modo DND</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Descanso visual</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Descanso visual activado</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Descanso visual desactivado</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Ajustes de Pantalla</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Descanso visual</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Encendido</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Claro</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Oscuro</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Desactivar el descanso visual</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Activar el descanso visual</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Ajustes de pantalla</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Tema: Claro</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Tema: Oscuro</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Tema: Automatico</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Efecto visual</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Claro</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Oscuro</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Modo elegante</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mantener visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mantener oculto</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultado inteligente</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicación</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Ajustes del muelle</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>No hay mensajes</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Ajustes de notificaciones</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Desactivar el modo DND</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Activar el modo DND</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Notificaciones</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Teclado en pantalla</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Alto rendimiento</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Balanceado</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Ahorro de energía</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Rendimiento equilibrado</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Energía</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Ajustes de energía</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacidad %1, %2 min restante</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacidad %1, %2 h %3 min restante</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Cargando %1, %2 min para completarse</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Cargando %1, %2 h %3 min para completarse</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacidad %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Cargando %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacidad %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacidad %1, completamente cargada</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Capacidad %1, no está cargando</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Bateria</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Cargando, calculando el tiempo de carga estimado</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Calcular el tiempo de uso restante</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>1% min restante</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 hr %2 min restante</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>No esta cargando</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Carga llena</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Cargando, %1 min para completarse</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Cargando, %1 hr %2 min hasta completarse</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Capacidad %1, %2 hr restante</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 hr restante</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Cargando %1, %2 hr hasta completarse</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Cargando, %1 hasta completarse</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Ajustes de energía</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Cerrar sesión</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ajustes de energía</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Actualizar y Apagar</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Actualizar y Reiniciar</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Cambiar usuario</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
    <message>
        <source>y</source>
        <translation>a</translation>
    </message>
    <message>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <source>d</source>
        <translation>d</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Ene</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Feb</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Abr</translation>
    </message>
    <message>
        <source>May</source>
        <translation>May</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Jun</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Jul</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Ago</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Sep</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Oct</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Nov</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Dic</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Abrir el calendario</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>lunes</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>martes</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>miércoles</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>jueves</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>viernes</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sábado</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>domingo</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Volumen</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Salida</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ajustes de sonido</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Activar sonido</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ajustes de sonido</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Sin dispositivos de salida</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volumen %1</translation>
    </message>
</context>
</TS>